@@ -7,9 +7,7 @@ from datetime import datetime
 import numpy as np
 import tables
 
-from scipy.interpolate import RegularGridInterpolator
 import h5py
-from scipy.ndimage import zoom
 import logging
 from datetime import timedelta
 from os.path import join, dirname, isfile
@@ -691,6 +689,8 @@ class ECMWF_variable(object):
         :param delta_day: deviation of database date from sensing date
         :param var_date:  date object
         """
+        from scipy.interpolate import RegularGridInterpolator  # import here to avoid static TLS ImportError
+
         self.logger = logging.getLogger() if logger is None else logger
         self.fn = ECMWF_download.db_path(variable, var_date, path_db)
 
@@ -723,6 +723,7 @@ class ECMWF_variable(object):
         :param force_bounds: True / False, force step between bounds of the actually loaded file
         :return: 2D array of variable
         """
+        from scipy.ndimage import zoom  # import here to avoid static TLS ImportError
 
         if step < self.steps[0] or step > self.steps[-1]:
             self.logger.warning(
