@@ -55,7 +55,6 @@ from .sicor import include_missing_spatial_samplings
 from .sicor import quality_check_data_ac_vs_clear_areas
 from .sicor import slp2spr
 from .sicor import wv, ac_interpolation, IO, prepare_s2_ac
-# from .sicor import wv_band_ratio
 from .sicor import get_ecmwf_data
 from .version import __version__
 
@@ -711,6 +710,11 @@ def ac_gms(s2img, options, logger=None, script=True):
     sensor_ac = "%s_AC" % sensor
     sensor_aot = "%s_AOT" % sensor
 
+    # downloading cloud mask, novelty detector, and AC LUT from Google Drive
+    logger.info("If not already available, download needed AC tables from Google Drive.")
+    from sicor.tables import get_tables
+    get_tables(sensor="s2")
+
     # preprocessing => derive cloud mask
     # if input image provides no cloud mask, derive own mask from cld_mask persistence file
     if not hasattr(s2img, "mask_clouds"):
